#ifndef __IOCTL__
#define __IOCTL__
/*
 * The purpose of this file is to allow UNIX-format ioctl calls to
 * be used with TurboC, via a locally-written version of the C ioctl
 * interface.  The file should basically include any ioctl calls
 * needed, as they are introduced.
 */

/* macros for defining UNIX-style commands */
#define pD(c,n) ((c)<<8|(n))	/* packed DOS ioctl */
#define hG(c,m) (0xf000|(c)<<8|(m))	/* handle generic ioctl */
#define bG(c,m) (0xe000|(c)<<8|(m))	/* block generic ioctl */

/* standard DOS ioctl (not packed) */
#define hGINF	0	/* H get device info */
#define hSINF	1	/* H set device info */
#define hIOCR	2	/* H read control string from handle */
#define hIOCW	3	/* H write control string to handle */
#define bIOCR	4	/* B read control string from blk dev */
#define bIOCW	5	/* B write control string to blk dev */
#define hGINP	6	/* H get input status */
#define hGOUT	7	/* H get output status */
#define bRMED	8	/* B block device removable? */
#define bLOCL	9	/* B block device local? */
#define hLOCL	10	/* H handle local? */
#define sSTRY	11	/* ? set retry count */
#define hGIOC	12	/* H handle generic ioctl */
#define bGIOC	13	/* B block device generic ioctl */
#define bGMAP	14	/* B get logical drive map */
#define bSMAP	15	/* B set logical drive map */
#define hQUER	16	/* H query handle */
#define bQUER	17	/* B query block */

/* DOS generic ioctl device categories */
#define TIOC	1	/* tty/COMx-flavored functions e.g. TIOCSETP */
#define CIOC	3	/* console/CON-specific ioctls */
#define PIOC	5	/* printer/LPTx-specific ioctls */
#define BIOC	8	/* block device-specific ioctls */
/* Additional generic ioctl device categories */
#define MIOC	7	/* (BSD) magtape e.g. MTIOCTOP */

/*
 * put ioctl commands and structures here as needed
 */

/* MIOC functions */
struct mtop {
	short mt_op;
	unsigned long mt_count;
};
#define MTIOCTOP	hG(MIOC,1)

/* operations */
#define MTWEOF	0	/* write an end-of-file record */
#define MTFSF	1	/* forward space file */
#define MTBSF	2	/* backward space file */
#define MTFSR	3	/* forward space record */
#define MTBSR	4	/* backward space record */
#define MTREW	5	/* rewind */
#define MTOFFL	6	/* rewind and put the drive offline */
#define MTNOP	7	/* no operation, sets status only */

/* mtget structure -- not UNIX format */
struct	mtget	{
	unsigned char tp_haid, tp_targid, tp_lun;/* in aspi-ready format */
	unsigned char tp_flags, tp_state;
	unsigned char tp_unit;			/* unit number */
	unsigned short tp_blksz;		/* blocksize for TPF_FIXED */
	/* for error reporting */
	unsigned char tp_status, tp_sense;
	int tp_opcode;			/* packed op code */
	unsigned tp_resid;
};
#define MTIOCGET	hG(MIOC,2)	/* generic ioctl version */
/*#define MTIOCGET	pD(hIOCR, sizeof(struct mtget))	/* ioctl read version */

/*#define MTIOCIEOT	hG(MIOC,3)	/* ignore end of tape errors */
/*#define MTIOCEEOT	hG(MIOC,4)	/* enable end of tape errors */

/* ASPI access */
#define ASPIGET	pD(hIOCR, sizeof(void far *))	/* ioctl read 4 bytes */

/* DOS 5 serial device generic ioctl defs */
#define TIOCSICNT	hG(TIOC,0x45)	/* set iteration count */
#define TIOCGICNT	hG(TIOC,0x65)	/* get iteration count */
#define TIOCSELCP	hG(TIOC,0x4a)	/* select code page */
#define TIOCSCPP	hG(TIOC,0x4c)	/* start code page prepare */
#define TIOCECPP	hG(TIOC,0x4d)	/* end code dage prepare */
#define TIOCQSCP	hG(TIOC,0x6a)	/* query selected code page */
#define TIOCQCPPL	hG(TIOC,0x6b)	/* query code-page prepare list */
/* DOS 5 console device generic ioctl defs */
#define CIOCSICNT	hG(CIOC,0x45)	/* set iteration count */
#define CIOCGICNT	hG(CIOC,0x65)	/* get iteration count */
#define CIOCSETM	hG(CIOC,0x5f)	/* set display mode */
#define CIOCGETM	hG(CIOC,0x7f)	/* get display mode */
#define CIOCSELCP	hG(CIOC,0x4a)	/* select code page */
#define CIOCSCPP	hG(CIOC,0x4c)	/* start code page prepare */
#define CIOCECPP	hG(CIOC,0x4d)	/* end code dage prepare */
#define CIOCQSCP	hG(CIOC,0x6a)	/* query selected code page */
#define CIOCQCPPL	hG(CIOC,0x6b)	/* query code-page prepare list */
/* DOS 5 parallel printer device generic ioctl defs */
#define PIOCSICNT	hG(PIOC,0x45)	/* set iteration count */
#define PIOCGICNT	hG(PIOC,0x65)	/* get iteration count */
#define PIOCSELCP	hG(PIOC,0x4a)	/* select code page */
#define PIOCSCPP	hG(PIOC,0x4c)	/* start code page prepare */
#define PIOCECPP	hG(PIOC,0x4d)	/* end code dage prepare */
#define PIOCQSCP	hG(PIOC,0x6a)	/* query selected code page */
#define PIOCQCPPL	hG(PIOC,0x6b)	/* query code-page prepare list */
/* DOS 5 block device generic ioctl defs */
#define BIOCSETP	bG(BIOC,0x40)	/* set device parameters */
#define BIOCGETP	bG(BIOC,0x60)	/* get device parameters */
#define BIOCWTRK	bG(BIOC,0x41)	/* write track */
#define BIOCRTRK	bG(BIOC,0x61)	/* read track */
#define BIOCFTRK	bG(BIOC,0x42)	/* format track */
#define BIOCVTRK	bG(BIOC,0x62)	/* verify track */
#define BIOCSETM	bG(BIOC,0x46)	/* set media id */
#define BIOCGETM	bG(BIOC,0x66)	/* get media id */
#define BIOCGTYP	bG(BIOC,0x68)	/* sense media type */

#endif __IOCTL__
